@@ -5,12 +5,12 @@
 // STDERR:
 
 Gtk = imports.gi.Gtk;
-Gtk.init(null, null);
+Gtk.init(Seed.argv);
 
 w = new Gtk.Window();
 vbox = new Gtk.VBox();
 
-closure = function(widget){Seed.print(widget);};
+closure = function(widget){print(widget);};
 w.add(vbox);
 
 vbox.pack_start(new Gtk.Label());
