@@ -5,11 +5,13 @@
 // STDERR:
 
 Gtk = imports.gi.Gtk;
+JSON = imports.JSON;
+
 Gtk.init(Seed.argv);
 
 function userdata_test(widget, user_data)
 {
-    Seed.print(JSON.stringify(user_data));
+    print(JSON.stringify(user_data));
 }
 
 w = new Gtk.Window();
